# EarthStat Geo Data Processing Documentation

Comprehensive guide to the `earthstat.geo_data_processing` module functionalities, designed for geospatial data manipulation and analysis.

## Raster Data Manipulation

### Clipping Raster Data for Area of Interest
::: earthstat.geo_data_processing.clip_raster

### Rescaling and Resampling for Data Uniformity
::: earthstat.geo_data_processing.rescale_resample_raster

## Shapefile Handling

### Efficient Shapefile Processing Techniques
::: earthstat.geo_data_processing.shapefile_process
